/*---[ netfilter-script.h ]-------------------------------------------
 * Copyright (C) 2000 Tomas Junnonen (majix@sci.fi)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Functions to write the netfilter shell scripts
 *--------------------------------------------------------------------*/

#ifndef _FIRESTARTER_NETFILTER_SCRIPT
#define _FIRESTARTER_NETFILTER_SCRIPT

#include <config.h>
#include <gnome.h>

void write_netfilter_script (void);

#endif
